@@ -9,6 +9,7 @@
 (American\ Typewriter American\ Typewriter Typewriter Proportional)
 (Andale\ Mono Andale Mono SansSerif)
 (Andika\ Basic Andika\ Basic SansSerif)
+(Antykwa\ Torunska Antykwa\ Torunska)
 (Apex\ Lake Apex\ Lake Bold Initials)
 (Apple\ Braille Apple\ Braille)
 (Apple\ Chancery Apple\ Chancery Calligraphic)
@@ -51,6 +52,7 @@
 (Bangla\ Sangam\ MN Bangla\ Sangam\ MN SansSerif)
 (Baoli\ SC Baoli\ SC)
 (Baskerville Baskerville)
+(BaskervilleF BaskervilleF)
 (Batang Batang)
 (BB\ Petie\ Boy BB\ Petie\ Boy)
 (Beirut Beirut)
@@ -136,9 +138,11 @@
 (Dufay Dufay)
 (Dustismo Dustismo SansSerif)
 (Dustismo\ Roman Dustismo\ Roman)
+(EB\ Garamond EB\ Garamond)
 (EB\ Garamond\ 12 EB\ Garamond\ 12)
 (EB\ Garamond\ Initials EB\ Garamond\ Initials)
 (Elvifrance Elvifrance Black Condensed SansSerif Caps Marker Comic)
+(Erewhon Erewhon)
 (Essays1743 Essays1743 Retro)
 (Estrangelo\ Edessa Estrangelo\ Edessa)
 (Euphemia\ UCAS Euphemia\ UCAS SansSerif)
@@ -152,6 +156,8 @@
 (Farah\ PUA Farah\ PUA)
 (Farisi Farisi)
 (Fava Fava Black SansSerif)
+(Fira\ Mono Fira Mono SansSerif)
+(Fira\ Sans Fira SansSerif)
 (Foglihten Foglihten)
 (FoglihtenBlackPcs FoglihtenPcs Black Wide Caps)
 (FoglihtenBPS01 FoglihtenBPS01 Oblique SansSerif Miscellaneous)
@@ -184,6 +190,9 @@
 (Gentium\ Book\ Basic Gentium\ Book\ Basic)
 (GentiumAlt GentiumAlt)
 (Georgia Georgia)
+(GFS\ Artemisia GFS\ Artemisia)
+(GFS\ Neohellenic GFS\ Neohellenic)
+(GFS\ Neohellenic\ Math GFS\ Neohellenic\ Math)
 (Gill\ Sans Gill SansSerif)
 (Gotika Gotika SansSerif Miscellaneous)
 (Gotika\ Apvalus Gotika\ Apvalus SansSerif Miscellaneous)
@@ -217,6 +226,7 @@
 (Helvetica\ Neue Helvetica\ Neue SansSerif)
 (Helvetica\ Neue\ DeskInterface Helvetica\ Neue\ DeskInterface SansSerif)
 (Herculanum Herculanum Ancient)
+(Heuristica Heuristica)
 (Hiragino\ Kaku\ Gothic\ Interface Hiragino\ Kaku\ Gothic\ Interface SansSerif)
 (Hiragino\ Kaku\ Gothic\ Pro Hiragino\ Kaku\ Gothic\ Pro SansSerif)
 (Hiragino\ Kaku\ Gothic\ ProN Hiragino\ Kaku\ Gothic\ ProN SansSerif)
@@ -246,6 +256,8 @@
 (Itsadzoke Itsadzoke Bold Caps)
 (ItsadzokeS01 ItsadzokeS01 Caps TripleStroke)
 (ItsadzokeS02 ItsadzokeS02 Caps TripleStroke)
+(Iwona Iwona SansSerif)
+(Iwona\ Cond Iwona Condensed SansSerif)
 (Junicode Junicode)
 (Jura Jura SansSerif)
 (Justus Justus)
@@ -261,6 +273,7 @@
 (Kawoszeh Kawoszeh)
 (Kedage Kedage)
 (Kefa Kefa)
+(Kepler\ Std Kepler\ Std)
 (Keyboard Keyboard)
 (Keytin Keytin Condensed SansSerif)
 (Khmer\ MN Khmer\ MN)
@@ -275,9 +288,16 @@
 (Kohinoor\ Telugu Kohinoor\ Telugu)
 (Kohinoor\ Telugu\ Semibold Kohinoor\ Telugu\ SemiBold)
 (Kokonor Kokonor)
+(KpMath Kepler\ Math)
+(KpMathSans Kepler\ Math SansSerif)
+(KpMono Kepler Mono SansSerif)
+(KpRoman Kepler)
+(KpSans Kepler SansSerif)
 (Krungthep Krungthep Bold Typewriter Proportional SansSerif)
 (KufiStandardGK KufiStandardGK)
 (KufiStandardGK\ PUA KufiStandardGK\ PUA)
+(Kurier Kurier SansSerif)
+(Kurier\ Cond Kurier Condensed SansSerif)
 (Lampoon Lampoon Black Condensed SciFi)
 (Lantinghei\ SC Lantinghei\ SC SansSerif)
 (Lantinghei\ TC Lantinghei\ TC SansSerif)
@@ -519,7 +539,7 @@
 (TeX\ Pandora\ Sans pandora SansSerif)
 (TeX\ Phoenician phoenician Ancient)
 (TeX\ Punk punk Pen Handwritten)
-(TeX\ Ralph\ Smith cal* Calligraphic)
+(TeX\ Ralph\ Smith cal* Italic Calligraphic)
 (TeX\ Runic\ Fut runic Ancient)
 (TeX\ Runic\ Futhol runic* Ancient)
 (TeX\ Runic\ Futhor runic** Ancient)
